package de.hft.stuttgart.citydoctor2.datastructure;


import java.io.Serial;
import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author Riegel
 */
public final class CompositeCollection {

    @Serial
    private static final long serialVersionUID = -1867197873443341287L;

    private GmlId gmlId;
    private List<ConcretePolygon> compositeMembers = new ArrayList<>();
    private List<CompositeCollection> childComposites = new ArrayList<>();

    public void addCompositeMember(ConcretePolygon p) {
        compositeMembers.add(p);
        p.setPartOfComposite(this);
    }

    public void addAllChildComposites(List<CompositeCollection> children) {
        childComposites.addAll(children);
    }

    public List<CompositeCollection> getChildComposites() {
        return childComposites;
    }

    public List<ConcretePolygon> getCompositeMembers() {
        List<ConcretePolygon> copy = new ArrayList<>(compositeMembers);
        for (CompositeCollection c : childComposites) {
            copy.addAll(c.getCompositeMembers());
        }
        return copy;
    }

    public List<ConcretePolygon> getNonRecursiveCompositeMembers() {
        return compositeMembers;
    }

    public void setGmlId(GmlId gmlId) {
        this.gmlId = gmlId;
    }

    public GmlId getGmlId() {
        return gmlId;
    }

}
