package de.hft.stuttgart.citydoctor2.gui;

import java.io.IOException;
import java.io.InputStream;
import java.util.Optional;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.hft.stuttgart.citydoctor2.check.Checker;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import javafx.application.Platform;
import javafx.scene.Node;
import javafx.scene.image.Image;
import javafx.scene.layout.HBox;

public class ValidationView extends View {
	
	private static final Logger logger = LogManager.getLogger(ValidationView.class);
	
	private Image viewLogo;
	private MainWindow mainWindow;
	private CityDoctorController controller;
	
	public ValidationView(MainWindow mainWindow, CityDoctorController controller) {
		this.mainWindow = mainWindow;
		this.controller = controller;
		try (InputStream inStream = MainWindow.class.getResourceAsStream("icons/error_stat32x32.png")) {
			viewLogo = new Image(inStream);
		} catch (IOException e) {
			logger.catching(e);
		}
	}
	
	@Override
	public Node getMainScreen() {
		return mainWindow.getMainContainer();
	}

	@Override
	public Optional<HBox> getToolbar() {
		return Optional.of(mainWindow.getMainToolbar().getToolBar());
	}

	@Override
	public void onHide() {
		Platform.runLater(() -> {
			mainWindow.unselectEverything();
			mainWindow.getMeshGroup().getChildren().clear();
			mainWindow.clearHighlights();
			mainWindow.getErrorTree().getRoot().getChildren().clear();
			mainWindow.getPolygonsView().getRoot().getChildren().clear();
			mainWindow.getVertexView().getRoot().getChildren().clear();
			mainWindow.getEdgeView().getRoot().getChildren().clear();
		});
	}

	@Override
	public void onShow(CityDoctorModel model, Checker checker) {
		if (model == null) {
			return;
		}
		controller.buildTrees();
		controller.updateFeatureTrees();
	}

	@Override
	public Image getViewLogo() {
		return viewLogo;
	}

	@Override
	public void initializeView(MainWindow mainWindow) {
		// already initialized
	}

}
