package de.hft.stuttgart.citydoctor2.healing;

import java.util.Collections;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.hft.stuttgart.citydoctor2.check.HealingID;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.check.error.AllPolygonsWrongOrientationError;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;

public class HealAllPolygonsWrongOrientationError implements HealingMethod {
	
	private static final Logger logger = LogManager.getLogger(HealAllPolygonsWrongOrientationError.class);
	
	@Override
	public boolean visit(AllPolygonsWrongOrientationError err, ModificationListener l) {
		logger.debug("Executing Repair for AllPolygonsWrongOrientationError");
		Geometry geom = err.getGeometry();
		for (Polygon p : geom.getPolygons()) {
			Collections.reverse(p.getExteriorRing().getVertices());
			for (LinearRing lr : p.getInnerRings()) {
				Collections.reverse(lr.getVertices());
			}
		}
		return true;
	}

	@Override
	public HealAllPolygonsWrongOrientationError createNew() {
		return new HealAllPolygonsWrongOrientationError();
	}

	@Override
	public HealingID getID() {
		return HealingID.S_ALL_POLYGONS_WRONG_ORIENTATION;
	}
}
